Alchemize - Simple de/serialization for Python
===============================================

Alchemize is designed to be a simple serialization and deserialization
library for Python. The primary use-case for Alchemize is to allow for
users to quickly build ReST clients using simple model mappings to
transform data from Python objects to a serializable form and vice-versa.

The power of Alchemize is that you can use it to augment existing
model structures from other libraries. For example, you can use Alchemize
to easily serialize your ORM models.

Installation
--------------

Alchemize is available on PyPI

.. code-block:: shell

    pip install alchemize


* Documentation: `ReadTheDocs <http://alchemize.readthedocs.org>`_
* Travis CI: |travis|
* Coverage: |codecov|

.. |travis| image:: https://travis-ci.org/jmvrbanac/alchemize.svg
    :target: https://travis-ci.org/jmvrbanac/alchemize

.. |codecov| image:: https://codecov.io/gh/jmvrbanac/alchemize/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/jmvrbanac/alchemize
